<?php

namespace App\Admin\Controllers;

use App\Models\Merchant;
use App\Models\OrderDivideRecord;
use App\Models\User;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use App\Admin\Actions\TransferToPlatForm;
use App\Models\StoreAdminUsers;

class OrderDivideRecordController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(OrderDivideRecord::with(['order', 'users']), function (Grid $grid) {
            $grid->model()->orderBy('id', 'DESC');
            $grid->column('id')->sortable();
            $grid->column('order.order_sn', '订单号');
            $grid->column('users.phone', '下单会员手机号');
            //$grid->column('og_id', '订单商品ID');
            $grid->column('order_price', '订单商品价格');
            $grid->column('divide_price', '佣金');
            //$grid->column('proportion', '分佣比例%');
            $grid->column('sh_type', '分佣类型')->display(function ($val) {
                return OrderDivideRecord::COMMISSION_TYPE[$val];
            });
            $grid->column('is_div', '是否已分账')->display(function ($val) {
                return $val == 1 ? '是' : '否';
            });
            $grid->column('um_id', '商户/员工')->display(function ($val) {
                $stype = $this->sh_type;
                $name = '';
                if ($stype == 0) {
                    $name = '平台';
                } else if ($stype == 3) {
                    $name = Merchant::where('id', $val)->value('name');
                }else if($stype == 5){
                    $name = StoreAdminUsers::where('id', $val)->value('name');
                }

                return $name;
            });
            $grid->column('remark', '备注')->width(80);
            $grid->column('created_at');
            //$grid->column('updated_at')->sortable();

            $grid->disableCreateButton();
            $grid->disableViewButton();
            $grid->disableEditButton();
            $grid->disableDeleteButton();
            $grid->disableRowSelector();

            // 添加导出字段映射
            $titles = [
                'id' => 'ID',
                'order.order_sn' => '订单号',
                'users.phone' => '会员手机号',
                'order_price' => '商品价格',
                'divide_price' => '分佣金额',
                'sh_type' => '分佣类型',
                'is_div' => '是否分账',
                'um_id' => '推荐人/商家',
                'created_at' => '创建时间'
            ];

            // 添加导出按钮
            $grid->export($titles)->rows(function ($rows) {
                foreach ($rows as $index => &$row) {
                    // 处理分佣类型显示
                    $row['is_div'] = $row['is_div'] == 1? '是' : '否';
                    $row['um_id'] = $row['um_id'] == 0? '平台' : $row['um_id'];

                    // 处理商家/员工显示
                    if ($row['sh_type'] == 0) {
                        $row['um_id'] = '平台';
                    } else if ($row['sh_type'] == 3) {
                        $row['um_id'] = Merchant::where('id',  $row['um_id'])->value('name');
                    }else if($row['sh_type'] == 5){
                        $row['um_id'] = StoreAdminUsers::where('id',  $row['um_id'])->value('name');
                    }

                    $row['sh_type'] = OrderDivideRecord::COMMISSION_TYPE[$row['sh_type']];
                    
                }
                return $rows;
            });

            $grid->filter(function (Grid\Filter $filter) {
                // 更改为 panel 布局
                $filter->panel();
                $filter->like('order.order_sn', '订单号')->width(3);
                $filter->like('users.phone', '下单会员手机号')->width(3);
                $filter->between('created_at', '创建时间')->datetime()->width(4);
            });





            //先注释，目前没有手动分账金额给平台说法
            // $grid->actions(function (Grid\Displayers\Actions $actions) {
            //     //分账给平台
            //     if ($actions->row->is_div == 0 && in_array($actions->row->sh_type, [1, 2])) {
            //         $actions->append(new TransferToPlatForm('分账给平台', $actions->row->id));
            //     }
            // });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new OrderDivideRecord(), function (Show $show) {
            $show->field('id');
            $show->field('order_id');
            $show->field('user_id');
            $show->field('og_id');
            $show->field('order_price');
            $show->field('divide_price');
            $show->field('proportion');
            $show->field('sh_type');
            $show->field('is_div');
            $show->field('remark');
            $show->field('um_id');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new OrderDivideRecord(), function (Form $form) {
            $form->display('id');
            $form->text('order_id');
            $form->text('user_id');
            $form->text('og_id');
            $form->text('order_price');
            $form->text('divide_price');
            $form->text('proportion');
            $form->text('sh_type');
            $form->text('is_div');
            $form->text('remark');
            $form->text('um_id');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
